searchData={"items":[{"type":"module","title":"Glossary","doc":"Minimalistic semantic translation system based on glossaries of lexemes and their expressions.","ref":"Glossary.html"},{"type":"module","title":"Concept - Glossary","doc":"A **lexeme** is a minimal semantic unit (e.g., `\"game.won\"`), and an **expression**\nis its localized realization in a specific language (e.g., `\"You won!\"`).\n\nA **glossary** is a collection of lexeme–expression mappings for a given language,\ntypically stored in a YAML file.\n\nThis module injects the functions `t/2` and `t/3` into the caller module for resolving\nthe expression of a lexeme in a given language using the loaded glossaries.","ref":"Glossary.html#module-concept"},{"type":"module","title":"Glossaries - Glossary","doc":"Each YAML file represents a **glossary** — a set of localized expressions.\n\nGlossaries are merged into a single lookup table keyed by `\"language.lexeme\"`.\n\nExample structure of glossary:\n\n    game.en.yml:\n      game:\n        won: \"You won!\"\n        lost: \"Game over.\"\n        score: \"Your score: {{score}}\"\n\n    game.ru.yml:\n      game:\n        won: \"Вы победили!\"\n        lost: \"Игра окончена.\"\n        score: \"Ваш счёт: {{score}}\"\n\n    user.en.yml:\n      greeting: \"Hello, {{name}}!\"\n\n    user.ru.yml:\n      greeting: \"Привет, {{name}}!\"","ref":"Glossary.html#module-glossaries"},{"type":"module","title":"Principles - Glossary","doc":"* Lexemes are **semantic** — they represent **meaning**, not UI position.\n    Good: `\"game.score\"`; Bad: `\"label.bottom_right\"`\n  * Group lexemes in YAML files by shared domain (e.g., `game`, `user`)\n  * Prefer flat structures with 2-level keys (domain + key)\n  * File name is not part of the lexeme — lookup is clean and abstracted\n  * Use `{{key}}` placeholders in expressions for interpolation","ref":"Glossary.html#module-principles"},{"type":"module","title":"Usage - Glossary","doc":"use Glossary, [\"game\", \"user\"]\n\nLoads:\n\n  - `game.en.yml`, `game.ru.yml`\n  - `user.en.yml`, `user.ru.yml`","ref":"Glossary.html#module-usage"},{"type":"module","title":"Expression Lookup - Glossary","doc":"t(\"game.won\", \"en\")\n    # => \"You won!\"\n\n    t(\"game.score\", \"en\", score: 42)\n    # => \"Your score: 42\"\n\n    t(\"user.greeting\", \"ru\", name: \"Алиса\")\n    # => \"Привет, Алиса!\"","ref":"Glossary.html#module-expression-lookup"},{"type":"macro","title":"Glossary.__using__/1","doc":"Injects the `t/2` function into the caller module for lexeme localization.\n\n`sources` is a list of relative paths (without extensions or locale suffixes) to YAML files\ncontaining lexeme–expression mappings.\n\nExample:\n\n    use Glossary, [\"../common\", \"project\"]","ref":"Glossary.html#__using__/1"},{"type":"module","title":"Glossary.Ecto","doc":"Provides the `hint/2` function for translating custom Ecto validation messages\nusing a localized glossary.\n\nDesigned for use in modules that define or consume `Ecto.Changeset` validations.","ref":"Glossary.Ecto.html"},{"type":"module","title":"Why? - Glossary.Ecto","doc":"Ecto allows adding errors with custom messages and metadata:\n\n    add_error(\n      changeset,\n      :field,\n      \"you're doing it wrong\",\n      foo: \"bar\",\n      validation: :foobar\n    )\n\nLater, you can retrieve that message from the changeset:\n\n    {\"you're doing it wrong\", [foo: \"bar\", validation: :foobar]}\n\n`Glossary.Ecto.hint/2` takes this `{message, opts}` tuple along with a `locale`\nand returns a localized, interpolated string — or falls back to the original.","ref":"Glossary.Ecto.html#module-why"},{"type":"module","title":"Usage - Glossary.Ecto","doc":"defmodule MyApp.Validation do\n      use Glossary.Ecto, [\"../locales/validation\"]\n    end\n\n    MyApp.Validation.hint({\"you're doing it wrong\", [foo: \"bar\", validation: :foobar]}, \"en\")\n    #=> \"you're doing bar wrong\"","ref":"Glossary.Ecto.html#module-usage"},{"type":"module","title":"Source format - Glossary.Ecto","doc":"The glossary is built from YAML files like this:\n\n    # validation.en.yml\n    validation:\n      foobar: \"you're doing {{foo}} wrong\"\n\n    # validation.ru.yml\n    validation:\n      foobar: \"вы неправильно делаете {{foo}}\"\n\nFile paths passed to `use Glossary.Ecto` should be base paths without extension or locale suffix.","ref":"Glossary.Ecto.html#module-source-format"},{"type":"module","title":"Glossary.Lexeme","doc":"Internal functions for working with glossary lexemes.\n\nThis module is not part of the public API.\nIt provides utilities to identify, qualify, and resolve localized expressions\nbased on Ecto-style validation metadata.","ref":"Glossary.Lexeme.html"},{"type":"function","title":"Glossary.Lexeme.identify/1","doc":"Builds a lexeme identifier from Ecto validation options.\n\nThe result is used to construct the glossary key. It attempts to match the most\nspecific form: `validation.key.kind.type`, then `validation.key.kind`, then `validation.key`.\n\nLogs a warning and returns `\"validation.unknown\"` if `:validation` is missing.","ref":"Glossary.Lexeme.html#identify/1"},{"type":"function","title":"Examples - Glossary.Lexeme.identify/1","doc":"identify(%{validation: :length, kind: :min, type: :string})\n    #=> \"validation.length.min.string\"\n\n    identify(%{validation: :required})\n    #=> \"validation.required\"","ref":"Glossary.Lexeme.html#identify/1-examples"},{"type":"function","title":"Glossary.Lexeme.lookup/4","doc":"Looks up a localized expression in the glossary by its fully qualified key.\n\nPerforms interpolation of placeholders in the form `{{key}}` using values from `bindings`.\nIf the key is not found, returns `fallback` or the key itself, and logs a warning.","ref":"Glossary.Lexeme.html#lookup/4"},{"type":"function","title":"Examples - Glossary.Lexeme.lookup/4","doc":"lookup(\"en.validation.required\", glossary, [], nil)\n    #=> \"can't be blank\"\n\n    lookup(\"en.validation.foo\", glossary, [name: \"Alice\"], nil)\n    #=> \"Hello, Alice!\"","ref":"Glossary.Lexeme.html#lookup/4-examples"},{"type":"function","title":"Glossary.Lexeme.qualify/2","doc":"Prepends a locale prefix to a lexeme to produce a fully qualified glossary key.","ref":"Glossary.Lexeme.html#qualify/2"},{"type":"function","title":"Examples - Glossary.Lexeme.qualify/2","doc":"qualify(\"validation.required\", \"en\")\n    #=> \"en.validation.required\"","ref":"Glossary.Lexeme.html#qualify/2-examples"},{"type":"module","title":"Glossary.Lexicon","doc":"Compiles YAML glossaries into a flat map of localized expressions.\n\nUsed internally by `Glossary` to build a lexicon of lexeme–expression mappings.","ref":"Glossary.Lexicon.html"},{"type":"function","title":"Glossary.Lexicon.compile/3","doc":"Compiles a list of YAML glossary files into a map of keys (`locale.lexeme`) to expressions.\n\nAutomatically marks each file as an external resource for recompilation tracking.","ref":"Glossary.Lexicon.html#compile/3"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}